--------------------------------------------------------------------------------
-- HoW-UI - Quest Journal Database.
--------------------------------------------------------------------------------
-- Quest data was sourced from http://esohead.com/quests
--------------------------------------------------------------------------------

--
-- Used for building data structure, only english is supported at the moment.
-- Not sure where I can get quest names for other languages.
--
local KEY_LANG = "en"

-- Map zoneIndex to zoneName and keep stats for zones.
local zones = {
    ["en"] = {
        -- Aldmeri Dominion
        ["178"] = "Auridon",
                -- Toothmaul Gully (public dungeon) x2
                -- The Banished Cells (group dungeon) x2
        ["180"] = "Grahtwood",
                -- Root Sunder Ruins (public dungeon) x2
                -- Elden Hollow (group dungeon) x2
        ["18"]  = "Greenshade",
                -- Rulanyil's Fall (public dungeon) x2
                -- City of Ash (group dungeon) x1
        ["294"] = "Khenarthi's Roost",
        ["11"]  = "Malabal Tor",
                -- Crimson Cove (public dungeon) x2
                -- Tempest Island (group dungeon) x1
        ["179"] = "Reaper's March",
                -- The Vile Manse (public dungeon) x2
                -- Selene's Web (group dungeon) x1
        -- Daggerfall Covenant
        ["17"]  = "Alik'r Desert",
                -- Lost City of the Na-Totambu (public dungeon) x2
                -- Volenfell (group dungeon) x1
        ["14"]  = "Bangkorai",
                -- Razak's Wheel (public dungeon) x2
                -- Blackheart Haven (group dungeon) x1
        ["293"] = "Betnikh",
        ["2"]   = "Glenumbra",
                -- Bad Man's Hallows (public dungeon) x2
                -- Spindleclutch (group dungeon) x2
        ["5"]   = "Rivenspire",
                -- Obsidian Scar (public dungeon) x1
                -- Crypt of Hearts (group dungeon) x1
        ["4"]   = "Stormhaven",
                -- Bonesnap Ruins (public dungeon) x2
                -- Wayrest Sewers (group dungeon) x2
        ["292"] = "Stros M'Kai",
        -- Ebonheart Pact
        ["110"] = "Bal Foyen",
        ["109"] = "Bleakrock Isle",
        ["10"]  = "Deshaan",
                -- Forgotten Crypts (public dungeon) x2
                -- Darkshade Caverns (group dungeon) x2
        ["15"]  = "Eastmarch",
                -- Hall of the Dead (public dungeon) x2
                -- Direfrost Keep (group dungeon) x1
        ["19"]  = "Shadowfen",
                -- Sanguine's Demesne (public dungeon) x2
                -- Arx Corinium (group dungeon) x1
        ["9"]   = "Stonefalls",
                -- Crow's Wood (public dungeon) x2
                -- Fungal Grotto (group dungeon) x2
        ["16"]  = "The Rift",
                -- Lion's Den (public dungeon) x2
                -- Blessed Crucible (group dungeon) x1
        -- Shared zones
        ["154"] = "Coldharbour",
                -- Village of the Lost (public dungeon) x2
                -- Vaults of Madness (group dungeon) x1
        ["37"]  = "Cyrodiil",
        ["352"]  = "Craglorn",
    },
}

-- Map quest types to name, used as replacement for zone name if needed.
local types = {
    ["en"] = {
        [tostring(QUEST_TYPE_AVA)] = "AvA",
        [tostring(QUEST_TYPE_AVA_GRAND)] = "AvA Grand",
        [tostring(QUEST_TYPE_AVA_GROUP)] = "AvA Group",
        [tostring(QUEST_TYPE_CLASS)] = "Class",
        [tostring(QUEST_TYPE_CRAFTING)] = "Crafting",
        [tostring(QUEST_TYPE_DUNGEON)] = "Dungeon",
        [tostring(QUEST_TYPE_GROUP)] = "Group",
        [tostring(QUEST_TYPE_GUILD)] = "Guild",
        [tostring(QUEST_TYPE_MAIN_STORY)] = "Main Story",
        [tostring(QUEST_TYPE_NONE)] = "None",
        [tostring(QUEST_TYPE_RAID)] = "Raid",
    },
}

local stats = {
    ["en"] = {
        -- Aldmeri Dominion
        ["Auridon"] = {
            total = 57,
            required = 37,
        },
        ["Grahtwood"] = {
            total = 48,
            required = 38,
        },
        ["Greenshade"] = {
            total = 53,
            required = 40,
        },
        ["Khenarthi's Roost"] = {
            total = 11,
            required = 0,
        },
        ["Malabal Tor"] = {
            total = 49,
            required = 40,
        },
        ["Reaper's March"] = {
            total = 63,
            required = 45,
        },
        -- Daggerfall Covenant
        ["Alik'r Desert"] = {
            total = 56,
            required = 42,
        },
        ["Bangkorai"] = {
            total = 60,
            required = 36,
        },
        ["Betnikh"] = {
            total = 9,
            required = 0,
        },
        ["Glenumbra"] = {
            total = 71,
            required = 53,
        },
        ["Rivenspire"] = {
            total = 50,
            required = 42,
        },
        ["Stormhaven"] = {
            total = 76,
            required = 60,
        },
        ["Stros M'Kai"] = {
            total = 15,
            required = 0,
        },
        -- Ebonheart Pact
        ["Bleakrock Isle"] = {
            total = 12,
            required = 0,
        },
        ["Bal Foyen"] = {
            total = 9,
            required = 0,
        },
        ["Deshaan"] = {
            total = 71,
            required = 55,
        },
        ["Eastmarch"] = {
            total = 55,
            required = 43,
        },
        ["Shadowfen"] = {
            total = 67,
            required = 51,
        },
        ["Stonefalls"] = {
            total = 80,
            required = 59,
        },
        ["The Rift"] = {
            total = 78,
            required = 61,
        },
        -- Shared zones
        ["Coldharbour"] = {
            total = 36,
            required = 30,
        },
        ["Cyrodiil"] = {
            total = 50,
            required = 50,
        },
        ["Craglorn"] = {
            total = 19,
            required = 0,
        },
    },
}

--- Quest entries grouped by zone.
local quests = {
    ["en"] = {
        -- Aldmeri Dominion
        ["Auridon"] = {
            ["A Hostile Situation"] = {
                level = 4,
            },
            ["A Village Awakened"] = {
                level = 10,
            },
            ["All the Fuss"] = {
                level = 8,
            },
            ["An Act of Kindness"] = {
                level = 11,
            },
            ["Assisting the Assistant"] = {
                level = 11,
            },
            ["Back to Skywatch"] = {
                level = 15,
            },
            ["Blessings of the Eight"] = {
                level = 13,
            },
            ["Breaking the Barrier"] = {
                level = 15,
            },
            ["Corruption Stones"] = {
                level = 8,
            },
            ["Depths of Madness"] = {
                level = 8,
            },
            ["Ensuring Security"] = {
                level = 3,
            },
            ["Eye of the Ancients"] = {
                level = 14,
            },
            ["Eye Spy"] = {
                level = 14,
            },
            ["Faith in the Family"] = {
                level = 14,
            },
            ["Final Blows"] = {
                level = 12,
            },
            ["Harsh Lesson"] = {
                level = 13,
            },
            ["In the Name of the Queen"] = {
                level = 8,
            },
            ["Lifting the Veil"] = {
                level = 11,
            },
            ["Lost Bet"] = {
                level = 15,
            },
            ["Missive to the Queen"] = {
                level = 11,
            },
            ["New in Town"] = {
                level = 4,
            },
            ["One of the Undaunted"] = {
                level = 12,
            },
            ["Plague of Phaer"] = {
                level = 7,
            },
            ["Preventative Measure"] = {
                level = 12,
            },
            ["Putting the Pieces Together"] = {
                level = 9,
            },
            ["Real Marines"] = {
                level = 5,
            },
            ["Relic Rescue"] = {
                level = 13,
            },
            ["Repentant Son"] = {
                level = 7,
            },
            ["Rightful Inheritance"] = {
                level = 15,
            },
            ["Rites of the Queen"] = {
                level = 8,
            },
            ["Sever All Ties"] = {
                level = 15,
            },
            ["Silent Village"] = {
                level = 10,
            },
            ["Silsailen Rescue"] = {
                level = 5,
            },
            ["Spirited Away"] = {
                level = 10,
            },
            ["Take Me Home"] = {
                level = 15,
            },
            ["Teldur's End"] = {
                level = 5,
            },
            ["The First Patient"] = {
                level = 7,
            },
            ["The Jester's Joke"] = {
                level = 15,
            },
            ["The Mallari-Mora"] = {
                level = 11,
            },
            ["The Racer"] = {
                level = 11,
            },
            ["The Serpent's Beacon"] = {
                level = 5,
            },
            ["The Unveiling"] = {
                level = 9,
            },
            ["The Veil Falls"] = {
                level = 11,
            },
            ["The Veiled Choice"] = {
                level = 12,
            },
            ["The Wayward Dagger"] = {
                level = 14,
            },
            ["Through the Ashes"] = {
                level = 12,
            },
            ["To Dawnbreak"] = {
                level = 11,
            },
            ["To Firsthold"] = {
                level = 12,
            },
            ["To Mathiisen"] = {
                level = 9,
            },
            ["To Skywatch"] = {
                level = 9,
            },
            ["To Tanzelwil"] = {
                level = 5,
            },
            ["Unaccounted Crew"] = {
                level = 4,
            },
            ["Wearing the Veil"] = {
                level = 11,
            },
            ["The Toothmaul Ploy"] = {
                level = 9,
                dungeon = "Toothmaul Gully",
            },
            ["Well-Armed Savages"] = {
                level = 9,
                dungeon = "Toothmaul Gully",
            },
            ["Banishing the Banished"] = {
                level = 12,
                dungeon = "The Banished Cells",
            },
            ["The Plan"] = {
                level = 50,
                dungeon = "The Banished Cells",
            },
        },
        ["Grahtwood"] = {
            ["A Chief Concern"] = {
                level = 22,
            },
            ["A Lasting Winter"] = {
                level = 23,
            },
            ["A Little on the Side"] = {
                level = 16,
            },
            ["A Lucrative Scheme"] = {
                level = 22,
            },
            ["A Silken Garb"] = {
                level = 17,
            },
            ["Ancient Stones, Ancient Words"] = {
                level = 23,
            },
            ["Blood Hunt"] = {
                level = 23,
            },
            ["Bosmer Insight"] = {
                level = 17,
            },
            ["Brackenleaf's Briars"] = {
                level = 17,
            },
            ["Caring for Kwama"] = {
                level = 22,
            },
            ["Carnival Conundrum"] = {
                level = 20,
            },
            ["Enemies at the Gate"] = {
                level = 22,
            },
            ["Eyes of Azura"] = {
                level = 19,
            },
            ["Fit to Rule"] = {
                level = 19,
            },
            ["Flipping the Coin"] = {
                level = 22,
            },
            ["Forbidden Love"] = {
                level = 21,
            },
            ["Forever Bound"] = {
                level = 16,
            },
            ["Heart of the Matter"] = {
                level = 19,
            },
            ["Keeper of Bones"] = {
                level = 18,
            },
            ["Light in the Darkness"] = {
                level = 23,
            },
            ["Lost in Study"] = {
                level = 21,
            },
            ["Lost Treasures"] = {
                level = 16,
            },
            ["Luck of the Albatross"] = {
                level = 16,
            },
            ["Pact Advocate"] = {
                level = 21,
            },
            ["Passage Denied"] = {
                level = 16,
            },
            ["Phantom Guilt"] = {
                level = 20,
            },
            ["Rare Imports"] = {
                level = 20,
            },
            ["Scars Never Fade"] = {
                level = 17,
            },
            ["Storgh's Bow"] = {
                level = 20,
            },
            ["The Blacksap's Hold"] = {
                level = 20,
            },
            ["The Enemy Within"] = {
                level = 22,
            },
            ["The Great Tree"] = {
                level = 16,
            },
            ["The Grip of Madness"] = {
                level = 18,
            },
            ["The Honor of the Queen"] = {
                level = 19,
            },
            ["The Innkeeper's Daughter"] = {
                level = 22,
            },
            ["The Orrery of Elden Root"] = {
                level = 23,
            },
            ["The Unquiet Dead"] = {
                level = 20,
            },
            ["The Wakening Dark"] = {
                level = 23,
            },
            ["The Wandering Minstrel"] = {
                level = 17,
            },
            ["The Wounded Wood"] = {
                level = 23,
            },
            ["Trouble at the Tree"] = {
                level = 16,
            },
            ["Unsafe Haven"] = {
                level = 16,
            },
            ["Until Death"] = {
                level = 19,
            },
            ["Wanted: Sgolag"] = {
                level = 24,
            },
            ["Forgotten Soul"] = {
                level = 16,
                dungeon = "Root Sunder Ruins",
            },
            ["If the Dead Could Talk"] = {
                level = 16,
                dungeon = "Root Sunder Ruins",
            },
            ["Ancient Remains"] = {
                level = 20,
                dungeon = "Elden Hollow",
            },
            ["Consuming Darkness"] = {
                level = 50,
                dungeon = "Elden Hollow",
            },
        },
        ["Greenshade"] = {
            ["A Storm Upon the Shore"] = {
                level = 29,
            },
            ["A Tangled Knot"] = {
                level = 26,
            },
            ["Aid for Bramblebreach"] = {
                level = 24,
            },
            ["Audience with the Wilderking"] = {
                level = 24,
            },
            ["Beasts of Falinesti"] = {
                level = 30,
            },
            ["Before the Storm"] = {
                level = 28,
            },
            ["Breaking the Ward"] = {
                level = 31,
            },
            ["Deadly Ambition"] = {
                level = 27,
            },
            ["Double Jeopardy"] = {
                level = 28,
            },
            ["Forthor's Cursed Axe"] = {
                level = 28,
            },
            ["Frighten the Fearsome"] = {
                level = 24,
            },
            ["Handmade Guardian"] = {
                level = 24,
            },
            ["Hunting the Mammoth"] = {
                level = 29,
            },
            ["Hunting the Troll"] = {
                level = 27,
            },
            ["Hunting the Wasp"] = {
                level = 26,
            },
            ["In the Belly of the Sea Hawk"] = {
                level = 27,
            },
            ["Lost in the Mist"] = {
                level = 27,
            },
            ["Manthir's Debt"] = {
                level = 26,
            },
            ["Mist and Shadow"] = {
                level = 27,
            },
            ["Moonhenge's Tear"] = {
                level = 31,
            },
            ["Mourning the Lost"] = {
                level = 29,
            },
            ["Naemon's Return"] = {
                level = 30,
            },
            ["Pelidil's End"] = {
                level = 29,
            },
            ["Report to Marbruk"] = {
                level = 30,
            },
            ["Retaking the Pass"] = {
                level = 30,
            },
            ["Right of Theft"] = {
                level = 29,
            },
            ["Scaled Captors"] = {
                level = 27,
            },
            ["Shades of Green"] = {
                level = 30,
            },
            ["Stone Cold"] = {
                level = 25,
            },
            ["Striking at the Heart"] = {
                level = 31,
            },
            ["Swift Justice"] = {
                level = 29,
            },
            ["The Amronal of Valenwood"] = {
                level = 28,
            },
            ["The Artisan"] = {
                level = 24,
            },
            ["The Blight of the Bosmer"] = {
                level = 29,
            },
            ["The Fading Tree"] = {
                level = 25,
            },
            ["The Falinesti Faithful"] = {
                level = 31,
            },
            ["The Flooded Grove"] = {
                level = 27,
            },
            ["The Flower of Youth"] = {
                level = 26,
            },
            ["The Misuses of Knowledge"] = {
                level = 28,
            },
            ["The Senche"] = {
                level = 31,
            },
            ["The Serpent Lord"] = {
                level = 28,
            },
            ["The Spinner's Tale"] = {
                level = 24,
            },
            ["The Staff of Magnus"] = {
                level = 26,
            },
            ["The Unfilled Order"] = {
                level = 32,
            },
            ["The Witch of Silatar"] = {
                level = 26,
            },
            ["Throne of the Wilderking"] = {
                level = 26,
            },
            ["To Velyn Harbor"] = {
                level = 31,
            },
            ["Troublemakers"] = {
                level = 25,
            },
            ["Veil of Illusion"] = {
                level = 28,
            },
            ["Woodhearth"] = {
                level = 26,
            },
            ["The Dead King"] = {
                level = 27,
                dungeon = "Rulanyil's Fall",
            },
            ["The Merethic Collection"] = {
                level = 27,
                dungeon = "Rulanyil's Fall",
            },
            ["Razor's Edge"] = {
                level = 28,
                dungeon = "City of Ash",
            },
        },
        ["Khenarthi's Roost"] = {
            ["A Pinch of Sugar"] = {
                level = 4,
            },
            ["Cast Adrift"] = {
                level = 4,
            },
            ["Dark Knowledge"] = {
                level = 4,
            },
            ["Moon-Sugar Medicament"] = {
                level = 4,
            },
            ["Storm on the Horizon"] = {
                level = 4,
            },
            ["Tears of the Two Moons"] = {
                level = 4,
            },
            ["The Family Business"] = {
                level = 4,
            },
            ["The Perils of Diplomacy"] = {
                level = 5,
            },
            ["The Root of the Problem"] = {
                level = 4,
            },
            ["The Tempest Unleashed"] = {
                level = 6,
            },
            ["To Auridon"] = {
                level = 5,
            },
        },
        ["Malabal Tor"] = {
            ["A Father's Promise"] = {
                level = 34,
            },
            ["A Nord in Need"] = {
                level = 32,
            },
            ["A Novel Idea"] = {
                level = 36,
            },
            ["A Tale Forever Told"] = {
                level = 36,
            },
            ["A Tangled Net"] = {
                level = 37,
            },
            ["A Wedding to Attend"] = {
                level = 35,
            },
            ["Arithiel"] = {
                level = 34,
            },
            ["Awakening"] = {
                level = 37,
            },
            ["Back to Rest"] = {
                level = 36,
            },
            ["Blind Man's Bluff"] = {
                level = 35,
            },
            ["Brothers and Bandits"] = {
                level = 32,
            },
            ["Buyer Beware"] = {
                level = 35,
            },
            ["Enemy of My Enemy"] = {
                level = 37,
            },
            ["For Everything a Season"] = {
                level = 35,
            },
            ["Fulfilling One's Fate"] = {
                level = 36,
            },
            ["House and Home"] = {
                level = 32,
            },
            ["Lost Daughter"] = {
                level = 32,
            },
            ["Nature's Best Friend"] = {
                level = 33,
            },
            ["One Fell Swoop"] = {
                level = 32,
            },
            ["Payment In Kind"] = {
                level = 35,
            },
            ["Raise the Curtain"] = {
                level = 33,
            },
            ["Reap What Is Sown"] = {
                level = 34,
            },
            ["Restore the Silvenar"] = {
                level = 37,
            },
            ["Sacred Prey, Hunt Profane"] = {
                level = 37,
            },
            ["Shards of Heresy"] = {
                level = 34,
            },
            ["Shipwrecked Sailors"] = {
                level = 36,
            },
            ["Shock to the System"] = {
                level = 35,
            },
            ["Something Rotten"] = {
                level = 35,
            },
            ["The Captain's Honor"] = {
                level = 36,
            },
            ["The Dark Mane"] = {
                level = 37,
            },
            ["The Dark Night of the Soul"] = {
                level = 37,
            },
            ["The Drublog of Dra'bul"] = {
                level = 32,
            },
            ["The Hound's Men"] = {
                level = 33,
            },
            ["The Hound's Plan"] = {
                level = 34,
            },
            ["The Maormer's Vessels"] = {
                level = 36,
            },
            ["The Misfortunate Minstrels"] = {
                level = 37,
            },
            ["The Prisoner of Jathsogur"] = {
                level = 35,
            },
            ["The Show Must Go On"] = {
                level = 33,
            },
            ["The Siege of Velyn Harbor"] = {
                level = 31,
            },
            ["The Soul Trap"] = {
                level = 34,
            },
            ["The Storm's Call"] = {
                level = 32,
            },
            ["The Summer Site"] = {
                level = 33,
            },
            ["The Tale of the Green Lady"] = {
                level = 33,
            },
            ["The Ties that Bind"] = {
                level = 37,
            },
            ["The Unkindest Cut"] = {
                level = 32,
            },
            ["Z'en and Mauloch"] = {
                level = 35,
            },
            ["Export Business"] = {
                level = 31,
                dungeon = "Crimson Cove",
            },
            ["Naval Intelligence"] = {
                level = 31,
                dungeon = "Crimson Cove",
            },
            ["Eye of the Storm"] = {
                level = 34,
                dungeon = "Tempest Island",
            },
        },
        ["Reaper's March"] = {
            ["A Door Into Moonlight"] = {
                level = 37,
            },
            ["A Foot in the Door"] = {
                level = 42,
            },
            ["A Night to Forget"] = {
                level = 40,
            },
            ["A Traitor's Luck"] = {
                level = 41,
            },
            ["An Affront to Mara"] = {
                level = 41,
            },
            ["An Offering"] = {
                level = 39,
            },
            ["Baan Dar's Bash"] = {
                level = 40,
            },
            ["Baan Dar's Boast"] = {
                level = 40,
            },
            ["Box of Riddles"] = {
                level = 40,
            },
            ["Desecrated Ground"] = {
                level = 40,
            },
            ["Down the Skeever Hole"] = {
                level = 37,
            },
            ["Eye on Arenthia"] = {
                level = 39,
            },
            ["Ezreba's Fate"] = {
                level = 38,
            },
            ["Ezzag's Bandits"] = {
                level = 41,
            },
            ["Fang Collector"] = {
                level = 39,
            },
            ["Gates of Fire"] = {
                level = 37,
            },
            ["Gentle Gardener"] = {
                level = 39,
            },
            ["Grim Situation"] = {
                level = 37,
            },
            ["Grimmer Still"] = {
                level = 37,
            },
            ["Hadran's Fall"] = {
                level = 38,
            },
            ["Hallowed To Arenthia"] = {
                level = 38,
            },
            ["Hallowed To Grimwatch"] = {
                level = 38,
            },
            ["Hallowed to Rawl'kha"] = {
                level = 39,
            },
            ["Haunting of Kalari"] = {
                level = 41,
            },
            ["History's Song"] = {
                level = 40,
            },
            ["How Few Remain"] = {
                level = 38,
            },
            ["Into the Vice Den"] = {
                level = 38,
            },
            ["Lizard Racing"] = {
                level = 38,
            },
            ["Loose Ends"] = {
                level = 41,
            },
            ["Moons Over Grimwatch"] = {
                level = 39,
            },
            ["Motes in the Moonlight"] = {
                level = 40,
            },
            ["Oath of Excision"] = {
                level = 37,
            },
            ["On the Doorstep"] = {
                level = 38,
            },
            ["Over the Edge"] = {
                level = 42,
            },
            ["Prisoners of the Sphinx"] = {
                level = 41,
            },
            ["Questionable Contract"] = {
                level = 40,
            },
            ["Rat Problems"] = {
                level = 41,
            },
            ["Small Town Problems"] = {
                level = 41,
            },
            ["Spikeball"] = {
                level = 38,
            },
            ["Stonefire Machinations"] = {
                level = 38,
            },
            ["Test of Faith"] = {
                level = 41,
            },
            ["The Arbordawn Cult"] = {
                level = 39,
            },
            ["The Champion Division"] = {
                level = 42,
            },
            ["The Champions at Rawl'kha"] = {
                level = 38,
            },
            ["The Colovian Occupation"] = {
                level = 38,
            },
            ["The Den of Lorkhaj"] = {
                level = 43,
            },
            ["The Fires of Dune"] = {
                level = 42,
            },
            ["The First Step"] = {
                level = 39,
            },
            ["The Golden Claw"] = {
                level = 39,
            },
            ["The Moonlit Path"] = {
                level = 43,
            },
            ["The Path to Moonmont"] = {
                level = 37,
            },
            ["The Sorcerer Division"] = {
                level = 42,
            },
            ["The Summoner Division"] = {
                level = 42,
            },
            ["The Swordmaster Division"] = {
                level = 42,
            },
            ["To Dune"] = {
                level = 40,
            },
            ["To Honor the Fallen"] = {
                level = 39,
            },
            ["To Moonmont"] = {
                level = 0,
            },
            ["To Rawl'kha"] = {
                level = 38,
            },
            ["To Saifa in Rawl'kha"] = {
                level = 39,
            },
            ["Troll Arena"] = {
                level = 38,
            },
            ["Song of the Spinner"] = {
                level = 39,
                dungeon = "The Vile Manse",
            },
            ["The Waking Dreamer"] = {
                level = 39,
                dungeon = "The Vile Manse",
            },
            ["Knowledge Gained"] = {
                level = 40,
                dungeon = "Selene's Web",
            },
        },
        -- Daggerfall Covenant
        ["Alik'r Desert"] = {
            ["A Blessing for the Dead"] = {
                level = 34,
            },
            ["A Reckoning with Uwafa"] = {
                level = 34,
            },
            ["Alasan's Plot"] = {
                level = 36,
            },
            ["Amputating the Hand"] = {
                level = 37,
            },
            ["Ash'abah Rising"] = {
                level = 32,
            },
            ["Badwater Mine"] = {
                level = 31,
            },
            ["Crawling Chaos"] = {
                level = 35,
            },
            ["Feathered Fiends"] = {
                level = 36,
            },
            ["Gone Missing"] = {
                level = 34,
            },
            ["Honoring the Dishonored"] = {
                level = 36,
            },
            ["Imperial Incursion"] = {
                level = 37,
            },
            ["In Search of the Ash'abah"] = {
                level = 31,
            },
            ["Kingdom in Mourning"] = {
                level = 37,
            },
            ["Lady Laurent's Favor"] = {
                level = 32,
            },
            ["Left at the Altar"] = {
                level = 34,
            },
            ["Lizard Racing"] = {
                level = 32,
            },
            ["Malignant Militia"] = {
                level = 35,
            },
            ["March of the Ra Gada"] = {
                level = 36,
            },
            ["Master of Leki's Blade"] = {
                level = 35,
            },
            ["Monkey Magic"] = {
                level = 31,
            },
            ["Morwha's Curse"] = {
                level = 33,
            },
            ["Past Due"] = {
                level = 35,
            },
            ["Past in Ruins"] = {
                level = 32,
            },
            ["Restoring the Ansei Wards"] = {
                level = 36,
            },
            ["Revered Ancestors"] = {
                level = 32,
            },
            ["Rise of the Dead"] = {
                level = 32,
            },
            ["Risen From the Depths"] = {
                level = 32,
            },
            ["Satak was the First Serpent"] = {
                level = 32,
            },
            ["Seize the Moment"] = {
                level = 31,
            },
            ["Shiri's Research"] = {
                level = 34,
            },
            ["Snakes in the Sands"] = {
                level = 36,
            },
            ["Temple's Treasures"] = {
                level = 37,
            },
            ["Tharayya's Trail"] = {
                level = 32,
            },
            ["The Impervious Vault"] = {
                level = 32,
            },
            ["The Initiation"] = {
                level = 33,
            },
            ["The Nature of Fate"] = {
                level = 31,
            },
            ["The Nature of Fate: Part Two"] = {
                level = 35,
            },
            ["The Oldest Orc"] = {
                level = 32,
            },
            ["The Real Snake"] = {
                level = 37,
            },
            ["The Scholar of Bergama"] = {
                level = 32,
            },
            ["The Search for Shiri"] = {
                level = 35,
            },
            ["The Search is Over"] = {
                level = 33,
            },
            ["Thwarting the Aldmeri Dominion"] = {
                level = 33,
            },
            ["Tracking the Hand"] = {
                level = 35,
            },
            ["Trapped in the Bluffs"] = {
                level = 36,
            },
            ["Trials of the Hero"] = {
                level = 36,
            },
            ["Trouble at Tava's Blessing"] = {
                level = 33,
            },
            ["Trouble at the Rain Catchers"] = {
                level = 32,
            },
            ["Tu'whacca's Breath"] = {
                level = 34,
            },
            ["Undying Loyalty"] = {
                level = 33,
            },
            ["Warship Designs"] = {
                level = 33,
            },
            ["Whose Wedding?"] = {
                level = 35,
            },
            ["Word from the Throne"] = {
                level = 32,
            },
            ["An Ill-Fated Venture"] = {
                level = 33,
                dungeon = "Lost City of the Na-Totambu",
            },
            ["Secrets of the Lost City"] = {
                level = 33,
                dungeon = "Lost City of the Na-Totambu",
            },
            ["Blood and Sand"] = {
                level = 34,
                dungeon = "Volenfell",
            },
        },
        ["Bangkorai"] = {
            ["A City in Black"] = {
                level = 37,
            },
            ["A Favor Between Kings"] = {
                level = 40,
            },
            ["A Grave Matter"] = {
                level = 37,
            },
            ["A Handful of Stolen Dreams"] = {
                level = 41,
            },
            ["A Marriage in Ruins"] = {
                level = 41,
            },
            ["A Master's Last Request"] = {
                level = 28,
            },
            ["A Thirst for Revolution"] = {
                level = 41,
            },
            ["A Token Trophy"] = {
                level = 41,
            },
            ["Back in Time"] = {
                level = 40,
            },
            ["Beyond the Call"] = {
                level = 37,
            },
            ["Conflicted Emotions"] = {
                level = 37,
            },
            ["Dark Wings"] = {
                level = 38,
            },
            ["Destroying the Dark Witnesses"] = {
                level = 38,
            },
            ["Fortune and Opportunity"] = {
                level = 30,
            },
            ["Freedom's Chains"] = {
                level = 38,
            },
            ["Hallin's Burden"] = {
                level = 41,
            },
            ["Heart of Evil"] = {
                level = 38,
            },
            ["Imperial Curiosity"] = {
                level = 42,
            },
            ["Imperial Infiltration"] = {
                level = 37,
            },
            ["Jharad's Notes"] = {
                level = 28,
            },
            ["Leading the Stand"] = {
                level = 37,
            },
            ["Mistress of the Lake"] = {
                level = 37,
            },
            ["News on the Garrison"] = {
                level = 40,
            },
            ["Present in Memory"] = {
                level = 40,
            },
            ["Publish or Perish"] = {
                level = 40,
            },
            ["Raiders at the Crossing"] = {
                level = 40,
            },
            ["Rendezvous at the Pass"] = {
                level = 40,
            },
            ["Report to Evermore"] = {
                level = 40,
            },
            ["Rising Against Onsi's Breath"] = {
                level = 42,
            },
            ["Scavenging for a Scarab"] = {
                level = 41,
            },
            ["Searching for the Searchers"] = {
                level = 40,
            },
            ["Storming the Garrison"] = {
                level = 40,
            },
            ["Striking Back"] = {
                level = 42,
            },
            ["Sunken Knowledge"] = {
                level = 38,
            },
            ["Supporting Force"] = {
                level = 26,
            },
            ["The Charge of Evermore"] = {
                level = 39,
            },
            ["The Constellation Shard"] = {
                level = 38,
            },
            ["The Crocodiles' Many Tears"] = {
                level = 29,
            },
            ["The Dead and the Dying"] = {
                level = 27,
            },
            ["The Heart of the Beast"] = {
                level = 40,
            },
            ["The Last Spriggan"] = {
                level = 38,
            },
            ["The Lion's Den"] = {
                level = 41,
            },
            ["The Parley"] = {
                level = 38,
            },
            ["The Prince's Health"] = {
                level = 40,
            },
            ["The Reachmen Camp"] = {
                level = 29,
            },
            ["The Returned"] = {
                level = 41,
            },
            ["The Shifting Sands of Fate"] = {
                level = 41,
            },
            ["The Waking Darkness"] = {
                level = 39,
            },
            ["The Water Stone"] = {
                level = 38,
            },
            ["The Will of the Woods"] = {
                level = 37,
            },
            ["To Aid the Enemy"] = {
                level = 41,
            },
            ["To Walk on Far Shores"] = {
                level = 42,
            },
            ["Tongues of Stone"] = {
                level = 41,
            },
            ["Trials and Tribulations"] = {
                level = 42,
            },
            ["Troll's Dessert"] = {
                level = 38,
            },
            ["Urenenya's Lament"] = {
                level = 41,
            },
            ["We Live In Fear"] = {
                level = 39,
            },
            ["The Covenant Infiltrator"] = {
                level = 40,
                dungeon = "Razak's Wheel",
            },
            ["The Mystery of Razak"] = {
                level = 40,
                dungeon = "Razak's Wheel",
            },
            ["Jumping Ship"] = {
                level = 40,
                dungeon = "Blackheart Haven",
            },
        },
        ["Betnikh"] = {
            ["Carzog's Demise"] = {
                level = 6,
            },
            ["Daughter of Seamount"] = {
                level = 6,
            },
            ["Farsight"] = {
                level = 6,
            },
            ["Into the Hills"] = {
                level = 6,
            },
            ["On to Glenumbra"] = {
                level = 6,
            },
            ["Prove Your Worth"] = {
                level = 6,
            },
            ["The Bloodthorn Plot"] = {
                level = 6,
            },
            ["Tormented Souls"] = {
                level = 6,
            },
            ["Unearthing the Past"] = {
                level = 6,
            },
        },
        ["Glenumbra"] = {
            ["A Brush With Death"] = {
                level = 11,
            },
            ["A Duke in Exile"] = {
                level = 9,
            },
            ["A Lingering Hope"] = {
                level = 11,
            },
            ["A Mysterious Curio"] = {
                level = 8,
            },
            ["A Step Back in Time"] = {
                level = 10,
            },
            ["Angof the Gravesinger"] = {
                level = 15,
            },
            ["Ash and Reprieve"] = {
                level = 5,
            },
            ["Back-Alley Murders"] = {
                level = 4,
            },
            ["Blood and the Crescent Moon"] = {
                level = 3,
            },
            ["Bloodthorn Assassins"] = {
                level = 4,
            },
            ["Champion of the Guardians"] = {
                level = 7,
            },
            ["Crocodile Bounty"] = {
                level = 12,
            },
            ["Crosswych Reclaimed"] = {
                level = 15,
            },
            ["Cursed Treasure"] = {
                level = 14,
            },
            ["Cutting Off the Source"] = {
                level = 11,
            },
            ["Disorganized Crime"] = {
                level = 8,
            },
            ["Farlivere's Gambit"] = {
                level = 8,
            },
            ["Forgotten Ancestry"] = {
                level = 14,
            },
            ["Fortune in Failure"] = {
                level = 14,
            },
            ["Garments by Odei"] = {
                level = 12,
            },
            ["Hidden in Flames"] = {
                level = 11,
            },
            ["Lady Eloise's Lockbox"] = {
                level = 8,
            },
            ["Legacy of Baelborne Rock"] = {
                level = 7,
            },
            ["Legitimate Interests"] = {
                level = 15,
            },
            ["Lineage of Tooth and Claw"] = {
                level = 9,
            },
            ["Mastering the Talisman"] = {
                level = 13,
            },
            ["Memento Mori"] = {
                level = 12,
            },
            ["Mists of Corruption"] = {
                level = 15,
            },
            ["One of the Undaunted"] = {
                level = 12,
            },
            ["Pride of the Lion Guard"] = {
                level = 9,
            },
            ["Purifying the Wyrd Tree"] = {
                level = 8,
            },
            ["Rally Cry"] = {
                level = 11,
            },
            ["Reclaiming the Elements"] = {
                level = 8,
            },
            ["Red Rook Resources"] = {
                level = 9,
            },
            ["Retaking Camlorn"] = {
                level = 11,
            },
            ["Ripple Effect"] = {
                level = 10,
            },
            ["Seeking the Guardians"] = {
                level = 7,
            },
            ["Servants of Ancient Kings"] = {
                level = 14,
            },
            ["Signals of Dominion"] = {
                level = 8,
            },
            ["Swine Thief"] = {
                level = 4,
            },
            ["Taking the Fight to the Enemy"] = {
                level = 13,
            },
            ["The Corpse Horde"] = {
                level = 13,
            },
            ["The Dagger's Edge"] = {
                level = 8,
            },
            ["The Dresan Index"] = {
                level = 8,
            },
            ["The End of Extortion"] = {
                level = 15,
            },
            ["The Fall of Faolchu"] = {
                level = 11,
            },
            ["The Ghosts of Westtry"] = {
                level = 12,
            },
            ["The Glenumbra Moors"] = {
                level = 10,
            },
            ["The Hidden Treasure"] = {
                level = 8,
            },
            ["The Jeweled Crown of Anton"] = {
                level = 15,
            },
            ["The Labyrinth"] = {
                level = 15,
            },
            ["The Lion Guard's Stand"] = {
                level = 13,
            },
            ["The Lost Patrol"] = {
                level = 13,
            },
            ["The Miners' Lament"] = {
                level = 15,
            },
            ["The Nameless Soldier"] = {
                level = 10,
            },
            ["The White Mask of Merien"] = {
                level = 11,
            },
            ["The Wyrd Sisters"] = {
                level = 6,
            },
            ["The Wyrd Tree's Roots"] = {
                level = 5,
            },
            ["To the Wyrd Tree"] = {
                level = 7,
            },
            ["Turning of the Trees"] = {
                level = 5,
            },
            ["Vines and Villains"] = {
                level = 13,
            },
            ["Vital Inheritance"] = {
                level = 9,
            },
            ["Wayward Scouts"] = {
                level = 8,
            },
            ["Werewolves to the North"] = {
                level = 8,
            },
            ["Wicked Trade"] = {
                level = 12,
            },
            ["Wolves in the Fold"] = {
                level = 9,
            },
            ["Wyrd and Coven"] = {
                level = 12,
            },
            ["Can't Take It With Them"] = {
                level = 5,
                dungeon = "Bad Man's Hallows",
            },
            ["Season of Harvest"] = {
                level = 5,
                dungeon = "Bad Man's Hallows",
            },
            ["Deadly Whispers"] = {
                level = 12,
                dungeon = "Spindleclutch",
            },
            ["Blood Relations"] = {
                level = 50,
                dungeon = "Spindleclutch",
            },
        },
        ["Rivenspire"] = {
            ["A Change of Heart"] = {
                level = 28,
            },
            ["A Dagger to the Heart"] = {
                level = 30,
            },
            ["A Lucky Break"] = {
                level = 28,
            },
            ["A Past Remembered"] = {
                level = 27,
            },
            ["A Spy in Shornhelm"] = {
                level = 25,
            },
            ["A Traitor's Tale"] = {
                level = 27,
            },
            ["Ancient Power"] = {
                level = 30,
            },
            ["Archaic Relics"] = {
                level = 28,
            },
            ["Assassin Hunter"] = {
                level = 25,
            },
            ["Children of Yokuda"] = {
                level = 24,
            },
            ["Crimes of the Past"] = {
                level = 26,
            },
            ["Dearly Departed"] = {
                level = 24,
            },
            ["Dream-Walk Into Darkness"] = {
                level = 24,
            },
            ["Fadeel's Freedom"] = {
                level = 25,
            },
            ["Favor for the Queen"] = {
                level = 25,
            },
            ["Fell's Justice"] = {
                level = 29,
            },
            ["Friend of Trolls"] = {
                level = 25,
            },
            ["Frightened Folk"] = {
                level = 29,
            },
            ["Guar Gone"] = {
                level = 30,
            },
            ["Hope Lost"] = {
                level = 26,
            },
            ["In the Doghouse"] = {
                level = 26,
            },
            ["Last Words"] = {
                level = 28,
            },
            ["Love Lost"] = {
                level = 30,
            },
            ["Northpoint in Peril"] = {
                level = 29,
            },
            ["Puzzle of the Pass"] = {
                level = 30,
            },
            ["Rusty Daggers"] = {
                level = 24,
            },
            ["Shedding the Past"] = {
                level = 27,
            },
            ["Shornhelm Divided"] = {
                level = 24,
            },
            ["The Assassin's List"] = {
                level = 26,
            },
            ["The Bandit"] = {
                level = 27,
            },
            ["The Barefoot Breton"] = {
                level = 30,
            },
            ["The Blood-Cursed Town"] = {
                level = 25,
            },
            ["The Blood-Splattered Shield"] = {
                level = 26,
            },
            ["The Concealing Veil"] = {
                level = 29,
            },
            ["The Crown of Shornhelm"] = {
                level = 25,
            },
            ["The Emerald Chalice"] = {
                level = 29,
            },
            ["The Lady's Keepsake"] = {
                level = 27,
            },
            ["The Last of Them"] = {
                level = 29,
            },
            ["The Liberation of Northpoint"] = {
                level = 30,
            },
            ["The Lightless Remnant"] = {
                level = 30,
            },
            ["The Lover"] = {
                level = 27,
            },
            ["The Price of Longevity"] = {
                level = 27,
            },
            ["The Road to Rivenspire"] = {
                level = 24,
            },
            ["The Sanctifying Flames"] = {
                level = 25,
            },
            ["The Spider's Cocoon"] = {
                level = 25,
            },
            ["The Wayward Son"] = {
                level = 27,
            },
            ["Threat of Death"] = {
                level = 30,
            },
            ["Under Siege"] = {
                level = 24,
            },
            ["Foul Deeds in the Deep"] = {
                level = 27,
                dungeon = "Obsidian Scar",
            },
            ["Lover's Torment"] = {
                level = 28,
                dungeon = "Crypt of Hearts",
            },
        },
        ["Stormhaven"] = {
            ["A Dangerous Dream"] = {
                level = 16,
            },
            ["A Family Affair"] = {
                level = 17,
            },
            ["A Final Request"] = {
                level = 21,
            },
            ["A Gang of Thugs"] = {
                level = 20,
            },
            ["A Look in the Mirror"] = {
                level = 22,
            },
            ["A Means to an End"] = {
                level = 20,
            },
            ["A Predator's Heart"] = {
                level = 23,
            },
            ["A Prison of Sleep"] = {
                level = 20,
            },
            ["A Ransom for Miranda"] = {
                level = 20,
            },
            ["A Woman Wronged"] = {
                level = 21,
            },
            ["Abominations from Beyond"] = {
                level = 21,
            },
            ["An Offering to Azura"] = {
                level = 20,
            },
            ["Another Omen"] = {
                level = 20,
            },
            ["Army at the Gates"] = {
                level = 17,
            },
            ["Azura's Aid"] = {
                level = 21,
            },
            ["Azura's Guardian"] = {
                level = 19,
            },
            ["Azura's Relics"] = {
                level = 23,
            },
            ["Blood Revenge"] = {
                level = 19,
            },
            ["Can't Leave Without Her"] = {
                level = 16,
            },
            ["Captive Crewmembers"] = {
                level = 16,
            },
            ["Curse of Skulls"] = {
                level = 21,
            },
            ["Divert and Deliver"] = {
                level = 17,
            },
            ["Do as I Say"] = {
                level = 20,
            },
            ["Dreams to Nightmares"] = {
                level = 19,
            },
            ["Ending the Ogre Threat"] = {
                level = 22,
            },
            ["Evidence Against Adima"] = {
                level = 21,
            },
            ["False Accusations"] = {
                level = 16,
            },
            ["False Knights"] = {
                level = 18,
            },
            ["Fire in the Fields"] = {
                level = 19,
            },
            ["General Godrun's Orders"] = {
                level = 22,
            },
            ["Gift from a Suitor"] = {
                level = 22,
            },
            ["Godrun's Dream"] = {
                level = 21,
            },
            ["Injured Spirit Wardens"] = {
                level = 19,
            },
            ["King Aphren's Sword"] = {
                level = 23,
            },
            ["Legacy of the Three"] = {
                level = 17,
            },
            ["Life of the Duchess"] = {
                level = 18,
            },
            ["Lighthouse Attack Plans"] = {
                level = 16,
            },
            ["Next of Kin"] = {
                level = 19,
            },
            ["Ogre Teeth"] = {
                level = 22,
            },
            ["Old Adventurers"] = {
                level = 22,
            },
            ["One Last Game"] = {
                level = 18,
            },
            ["Plan of Attack"] = {
                level = 17,
            },
            ["Plowshares to Swords"] = {
                level = 23,
            },
            ["Pursuing the Shard"] = {
                level = 19,
            },
            ["Rat in a Trap"] = {
                level = 20,
            },
            ["Repair Koeglin Lighthouse"] = {
                level = 16,
            },
            ["Retaking Firebrand Keep"] = {
                level = 18,
            },
            ["Revenge Against Rama"] = {
                level = 20,
            },
            ["Rozenn's Dream"] = {
                level = 17,
            },
            ["Saving Hosni"] = {
                level = 21,
            },
            ["Scamp Invasion"] = {
                level = 17,
            },
            ["Sir Hughes' Fate"] = {
                level = 17,
            },
            ["Stolen Ashes"] = {
                level = 20,
            },
            ["The Debt Collector's Debts"] = {
                level = 20,
            },
            ["The Dreugh Threat"] = {
                level = 20,
            },
            ["The Flame of Dissent"] = {
                level = 18,
            },
            ["The Gate to Quagmire"] = {
                level = 20,
            },
            ["The Perfect Burial"] = {
                level = 21,
            },
            ["The Return of the Dream Shard"] = {
                level = 21,
            },
            ["The Safety of the Kingdom"] = {
                level = 18,
            },
            ["The Signet Ring"] = {
                level = 20,
            },
            ["The Slavers"] = {
                level = 16,
            },
            ["The Slumbering Farmer"] = {
                level = 16,
            },
            ["The Sower Reaps"] = {
                level = 20,
            },
            ["They Dragged Him Away"] = {
                level = 20,
            },
            ["To Alcaire Castle"] = {
                level = 16,
            },
            ["Tracking Sir Hughes"] = {
                level = 18,
            },
            ["Two Sides to Every Coin"] = {
                level = 17,
            },
            ["Unanswered Questions"] = {
                level = 17,
            },
            ["Vaermina's Gambit"] = {
                level = 21,
            },
            ["Waiting for Word"] = {
                level = 20,
            },
            ["Word from the Dead"] = {
                level = 20,
            },
            ["Lost Lions"] = {
                level = 18,
                dungeon = "Bonesnap Ruins",
            },
            ["Repairing the Cage"] = {
                level = 18,
                dungeon = "Bonesnap Ruins",
            },
            ["Deception in the Dark"] = {
                level = 20,
                dungeon = "Wayrest Sewers",
            },
            ["No Second Chances"] = {
                level = 50,
                dungeon = "Wayrest Sewers",
            },
        },
        ["Stros M'Kai"] = {
            ["Buried Secrets"] = {
                level = 4,
            },
            ["Dead Man's Wrist"] = {
                level = 2,
            },
            ["Goblin Marq"] = {
                level = 4,
            },
            ["Innocent Scoundrel"] = {
                level = 4,
            },
            ["Izad's Treasure"] = {
                level = 4,
            },
            ["Last Night"] = {
                level = 4,
            },
            ["Like Moths to a Candle"] = {
                level = 4,
            },
            ["Moment of Truth"] = {
                level = 4,
            },
            ["Sphere Assembly"] = {
                level = 4,
            },
            ["Tarnish the Crown"] = {
                level = 4,
            },
            ["The Broken Spearhead"] = {
                level = 4,
            },
            ["The Spearhead's Captain"] = {
                level = 4,
            },
            ["The Spearhead's Crew"] = {
                level = 4,
            },
            ["Tip of the Spearhead"] = {
                level = 5,
            },
            ["Washed Ashore"] = {
                level = 4,
            },
        },
        -- Ebonheart Pact
        ["Bleakrock Isle"] = {
            ["A Beginning at Bleakrock"] = {
                level = 4,
            },
            ["At Frost's Edge"] = {
                level = 4,
            },
            ["Dangerous Webs"] = {
                level = 4,
            },
            ["Escape from Bleakrock"] = {
                level = 5,
            },
            ["Hozzin's Folly"] = {
                level = 4,
            },
            ["Lost on Bleakrock"] = {
                level = 4,
            },
            ["Sparking the Flame"] = {
                level = 4,
            },
            ["The Frozen Man"] = {
                level = 4,
            },
            ["The Missing of Bleakrock"] = {
                level = 4,
            },
            ["Tracking the Game"] = {
                level = 4,
            },
            ["Underfoot"] = {
                level = 4,
            },
            ["What Waits Beneath"] = {
                level = 4,
            },
        },
        ["Bal Foyen"] = {
            ["Breaking the Tide"] = {
                level = 6,
            },
            ["Crossroads"] = {
                level = 6,
            },
            ["Finding the Family"] = {
                level = 6,
            },
            ["If By Sea"] = {
                level = 6,
            },
            ["Salt of the Earth"] = {
                level = 6,
            },
            ["The Bard of Hounds"] = {
                level = 6,
            },
            ["Unorthodox Tactics"] = {
                level = 6,
            },
            ["Warning Davon's Watch"] = {
                level = 4,
            },
            ["Zeren in Peril"] = {
                level = 6,
            },
        },
        ["Deshaan"] = {
            ["A Blow for Order"] = {
                level = 24,
            },
            ["A Fair Warning"] = {
                level = 23,
            },
            ["A Favor Returned"] = {
                level = 19,
            },
            ["A Letter for Deshaan"] = {
                level = 15,
            },
            ["A Saint Asunder"] = {
                level = 23,
            },
            ["A Service for the Dead"] = {
                level = 21,
            },
            ["A Timely Matter"] = {
                level = 17,
            },
            ["Bad Medicine"] = {
                level = 15,
            },
            ["Bad Soldiers"] = {
                level = 23,
            },
            ["Burning Revenge"] = {
                level = 17,
            },
            ["By Invitation Only"] = {
                level = 21,
            },
            ["Carving Cuttle"] = {
                level = 21,
            },
            ["Challenge the Tide"] = {
                level = 16,
            },
            ["Chasing the Magistrix"] = {
                level = 21,
            },
            ["Cold-Blooded Vengeance"] = {
                level = 23,
            },
            ["Cultural Exchange"] = {
                level = 19,
            },
            ["Death Trap"] = {
                level = 18,
            },
            ["Dissonant Commands"] = {
                level = 18,
            },
            ["Fighting Back"] = {
                level = 17,
            },
            ["For Their Own Protection"] = {
                level = 17,
            },
            ["Healing Hearts"] = {
                level = 23,
            },
            ["Hiding in Plain Sight"] = {
                level = 17,
            },
            ["Honor Bound"] = {
                level = 17,
            },
            ["Into the Mouth of Madness"] = {
                level = 24,
            },
            ["Intruders in Deshaan"] = {
                level = 16,
            },
            ["Mechanical Murder"] = {
                level = 18,
            },
            ["Message to Mournhold"] = {
                level = 19,
            },
            ["Motive for Heresy"] = {
                level = 24,
            },
            ["Mournhold Market Misery"] = {
                level = 22,
            },
            ["Nothing Left to Waste"] = {
                level = 18,
            },
            ["Oath Breaker"] = {
                level = 16,
            },
            ["Onward to Shadowfen"] = {
                level = 24,
            },
            ["Payback"] = {
                level = 18,
            },
            ["Plague Bringer"] = {
                level = 18,
            },
            ["Proprietary Formula"] = {
                level = 15,
            },
            ["Race For the Cure"] = {
                level = 15,
            },
            ["Ratting Them Out"] = {
                level = 17,
            },
            ["Remembering Risa"] = {
                level = 20,
            },
            ["Rescue and Revenge"] = {
                level = 22,
            },
            ["Restless Spirits"] = {
                level = 22,
            },
            ["Ritual of Anguish"] = {
                level = 16,
            },
            ["Rules and Regulations"] = {
                level = 23,
            },
            ["School Daze"] = {
                level = 21,
            },
            ["Search and Rescue"] = {
                level = 21,
            },
            ["Strange Guard Beasts"] = {
                level = 23,
            },
            ["Supply Run"] = {
                level = 22,
            },
            ["That Which Matters Most"] = {
                level = 18,
            },
            ["The Dungeon Delvers"] = {
                level = 18,
            },
            ["The Judgment of Veloth"] = {
                level = 24,
            },
            ["The Light Fantastic"] = {
                level = 18,
            },
            ["The Llodos Plague"] = {
                level = 17,
            },
            ["The Medallions of Saint Veloth"] = {
                level = 17,
            },
            ["The Mournhold Underground"] = {
                level = 19,
            },
            ["The Naked Nord"] = {
                level = 16,
            },
            ["The Ravaged Village"] = {
                level = 23,
            },
            ["The Saving of Silent Mire"] = {
                level = 23,
            },
            ["The Seal of Three"] = {
                level = 21,
            },
            ["The Soldier's Alibi"] = {
                level = 23,
            },
            ["The Trial of the Ghost Snake"] = {
                level = 20,
            },
            ["The Wounds in the World"] = {
                level = 23,
            },
            ["Tracking the Plague"] = {
                level = 18,
            },
            ["Trade Negotiations"] = {
                level = 20,
            },
            ["Unwanted Guests"] = {
                level = 17,
            },
            ["Vengeance of the Oppressed"] = {
                level = 19,
            },
            ["Vision Quest"] = {
                level = 21,
            },
            ["What Lies Beneath"] = {
                level = 23,
            },
            ["You Have to Break a Few"] = {
                level = 17,
            },
            ["A Bitter Pill"] = {
                level = 16,
                dungeon = "Forgotten Crypts",
            },
            ["A Family Divided"] = {
                level = 16,
                dungeon = "Forgotten Crypts",
            },
            ["Mine All Mine"] = {
                level = 20,
                dungeon = "Darkshade Caverns",
            },
            ["What Was Lost"] = {
                level = 50,
                dungeon = "Darkshade Caverns",
            },
        },
        ["Eastmarch"] = {
            ["A Brother's Revenge"] = {
                level = 32,
            },
            ["A Council of Thanes"] = {
                level = 36,
            },
            ["A Cure For Droi"] = {
                level = 31,
            },
            ["A Dying Wish"] = {
                level = 36,
            },
            ["A Friend in Mead"] = {
                level = 32,
            },
            ["A Right to Live"] = {
                level = 34,
            },
            ["Alchemical Analysis"] = {
                level = 34,
            },
            ["Bath Time"] = {
                level = 35,
            },
            ["Best of the Best"] = {
                level = 34,
            },
            ["Blindsided"] = {
                level = 33,
            },
            ["Collector of Pelts"] = {
                level = 32,
            },
            ["Dark Deeds"] = {
                level = 35,
            },
            ["Dear Cousins"] = {
                level = 33,
            },
            ["Do Kill the Messenger"] = {
                level = 34,
            },
            ["Eternal Slumber"] = {
                level = 35,
            },
            ["For Kyne's Honor"] = {
                level = 31,
            },
            ["Giant Problems"] = {
                level = 32,
            },
            ["Gods Save the King"] = {
                level = 35,
            },
            ["In Search of Kireth Vanos"] = {
                level = 37,
            },
            ["Kireth's Amazing Plan"] = {
                level = 37,
            },
            ["Labor Dispute"] = {
                level = 34,
            },
            ["Land Dispute"] = {
                level = 36,
            },
            ["Lifeline"] = {
                level = 35,
            },
            ["Making Amends"] = {
                level = 36,
            },
            ["Merriment and Mystery"] = {
                level = 36,
            },
            ["Mystery Metal"] = {
                level = 34,
            },
            ["Nature's Accord"] = {
                level = 34,
            },
            ["Of Councils and Kings"] = {
                level = 35,
            },
            ["One Victor, One King"] = {
                level = 33,
            },
            ["Our Poor Town"] = {
                level = 35,
            },
            ["Party Planning"] = {
                level = 33,
            },
            ["Pilfered Urn"] = {
                level = 35,
            },
            ["Relative Matters"] = {
                level = 37,
            },
            ["Security Details"] = {
                level = 36,
            },
            ["Shadows Over Windhelm"] = {
                level = 33,
            },
            ["Shrine of Corruption"] = {
                level = 31,
            },
            ["Sleep for the Dead"] = {
                level = 33,
            },
            ["Sleeping on the Job"] = {
                level = 34,
            },
            ["Sneak Peak"] = {
                level = 36,
            },
            ["Snow and Flame"] = {
                level = 37,
            },
            ["Songs of Sovngarde"] = {
                level = 38,
            },
            ["Sounds of Alarm"] = {
                level = 33,
            },
            ["Strange Allies"] = {
                level = 33,
            },
            ["Swamp to Snow"] = {
                level = 31,
            },
            ["The Better of Two Evils"] = {
                level = 35,
            },
            ["The Konunleikar"] = {
                level = 33,
            },
            ["The Pride of a Prince"] = {
                level = 34,
            },
            ["The Siege of Cradlecrush"] = {
                level = 33,
            },
            ["The War Council"] = {
                level = 34,
            },
            ["Torn Asunder"] = {
                level = 37,
            },
            ["Victory at Morvunskar"] = {
                level = 33,
            },
            ["Windhelm's Champion"] = {
                level = 33,
            },
            ["Lost Crown"] = {
                level = 31,
                dungeon = "Hall of the Dead",
            },
            ["On a Dare"] = {
                level = 31,
                dungeon = "Hall of the Dead",
            },
            ["Nobles' Rest"] = {
                level = 34,
                dungeon = "Direfrost Keep",
            },
        },
        ["Shadowfen"] = {
            ["A Final Release"] = {
                level = 30,
            },
            ["A Last Reminder"] = {
                level = 25,
            },
            ["A Life of Privilege"] = {
                level = 26,
            },
            ["A Pirate Parley"] = {
                level = 26,
            },
            ["A Poisoned Heart"] = {
                level = 30,
            },
            ["A Stranger Uninvited"] = {
                level = 28,
            },
            ["And Throw Away The Key"] = {
                level = 30,
            },
            ["Bound to the Bog"] = {
                level = 25,
            },
            ["Broken Apart"] = {
                level = 28,
            },
            ["Buried in the Past"] = {
                level = 28,
            },
            ["Captive Souls"] = {
                level = 25,
            },
            ["Captured Time"] = {
                level = 29,
            },
            ["Catch the Lightning"] = {
                level = 29,
            },
            ["Children of the Hist"] = {
                level = 28,
            },
            ["Clarity"] = {
                level = 27,
            },
            ["Cold-Blooded Revenge"] = {
                level = 27,
            },
            ["Cracking the Egg"] = {
                level = 26,
            },
            ["Deep Disturbance"] = {
                level = 30,
            },
            ["Dreams From the Hist"] = {
                level = 29,
            },
            ["Eyes of the Enemy"] = {
                level = 26,
            },
            ["Getting to the Truth"] = {
                level = 24,
            },
            ["Hushed Whispers"] = {
                level = 24,
            },
            ["Into the Mire"] = {
                level = 27,
            },
            ["Into the Temple"] = {
                level = 29,
            },
            ["Keepers of the Shell"] = {
                level = 28,
            },
            ["King of Dust"] = {
                level = 29,
            },
            ["Last One Standing"] = {
                level = 26,
            },
            ["Lost Pilgrimage"] = {
                level = 29,
            },
            ["Lost to the Mire"] = {
                level = 27,
            },
            ["Missing in the Mire"] = {
                level = 30,
            },
            ["Missing Son"] = {
                level = 27,
            },
            ["Of Dubious Value"] = {
                level = 29,
            },
            ["Outside Interference"] = {
                level = 28,
            },
            ["Overrun"] = {
                level = 29,
            },
            ["Pull the Last Fang"] = {
                level = 28,
            },
            ["Riches Beyond Measure"] = {
                level = 29,
            },
            ["Saving the Relics"] = {
                level = 26,
            },
            ["Scales of Retribution"] = {
                level = 30,
            },
            ["Schism"] = {
                level = 25,
            },
            ["Scouring the Mire"] = {
                level = 24,
            },
            ["Shadowfen Smorgasbord"] = {
                level = 24,
            },
            ["Strength of the Father"] = {
                level = 27,
            },
            ["The Bargain's End"] = {
                level = 25,
            },
            ["The Dominion's Alchemist"] = {
                level = 31,
            },
            ["The Dream of the Hist"] = {
                level = 31,
            },
            ["The Fangs of Sithis"] = {
                level = 28,
            },
            ["The Keystone"] = {
                level = 30,
            },
            ["The Mnemic Egg"] = {
                level = 28,
            },
            ["The Ones Left Behind"] = {
                level = 30,
            },
            ["The Skin-Stealer's Lair"] = {
                level = 26,
            },
            ["The Swamp's Embrace"] = {
                level = 31,
            },
            ["The Thin Ones"] = {
                level = 25,
            },
            ["The Tree-Minder's Fate"] = {
                level = 27,
            },
            ["Three Tender Souls"] = {
                level = 24,
            },
            ["Threefold Folly"] = {
                level = 26,
            },
            ["Trail of the Skin-Stealer"] = {
                level = 26,
            },
            ["Trials of the Burnished Scales"] = {
                level = 29,
            },
            ["Unbridled Wealth"] = {
                level = 25,
            },
            ["Unwelcome Guests"] = {
                level = 24,
            },
            ["Vigil's End"] = {
                level = 31,
            },
            ["Warm Welcome"] = {
                level = 26,
            },
            ["What Happened at Murkwater"] = {
                level = 30,
            },
            ["Whispers of the Wisps"] = {
                level = 28,
            },
            ["Will of the Broken"] = {
                level = 26,
            },
            ["Foreign Vintage"] = {
                level = 25,
                dungeon = "Sanguine's Demesne",
            },
            ["Life of the Party"] = {
                level = 25,
                dungeon = "Sanguine's Demesne",
            },
            ["Force of Nature"] = {
                level = 28,
                dungeon = "Arx Corinium",
            },
        },
        ["Stonefalls"] = {
            ["A Bit of Sport"] = {
                level = 10,
            },
            ["A Gathering of Guar"] = {
                level = 15,
            },
            ["A Goblin's Affection"] = {
                level = 10,
            },
            ["A Higher Priority"] = {
                level = 11,
            },
            ["A Storm Broken"] = {
                level = 11,
            },
            ["A Story Told in Footprints"] = {
                level = 13,
            },
            ["Aggressive Negotiations"] = {
                level = 15,
            },
            ["An Unwanted Twin"] = {
                level = 13,
            },
            ["Assisting Davon's Watch"] = {
                level = 8,
            },
            ["Breaking Fort Virak"] = {
                level = 12,
            },
            ["City at the Spire"] = {
                level = 12,
            },
            ["City Under Siege"] = {
                level = 4,
            },
            ["Cleansing the Past"] = {
                level = 10,
            },
            ["Climbing the Spire"] = {
                level = 15,
            },
            ["Close the Scamp Caves"] = {
                level = 8,
            },
            ["Darkvale Brews"] = {
                level = 14,
            },
            ["Delaying the Daggers"] = {
                level = 4,
            },
            ["Desperate Souls"] = {
                level = 7,
            },
            ["Divine Favor"] = {
                level = 13,
            },
            ["Enlightenment Needs Salt"] = {
                level = 11,
            },
            ["Enslaved in Death"] = {
                level = 5,
            },
            ["Evening the Odds"] = {
                level = 12,
            },
            ["Exquisite Tears"] = {
                level = 5,
            },
            ["From the Wastes"] = {
                level = 13,
            },
            ["Giving for the Greater Good"] = {
                level = 5,
            },
            ["Hunting Invaders"] = {
                level = 11,
            },
            ["In With the Tide"] = {
                level = 8,
            },
            ["Kinsman's Revenge"] = {
                level = 11,
            },
            ["Legacy of the Ancestors"] = {
                level = 3,
            },
            ["Mystery of Othrenis"] = {
                level = 7,
            },
            ["Night of the Soul"] = {
                level = 10,
            },
            ["One of the Undaunted"] = {
                level = 12,
            },
            ["Opening the Portal"] = {
                level = 15,
            },
            ["Percussive Ranching"] = {
                level = 6,
            },
            ["Peril at the Pools"] = {
                level = 10,
            },
            ["Protecting the Hall"] = {
                level = 11,
            },
            ["Proving Trust"] = {
                level = 6,
            },
            ["Quiet the Ringing Bell"] = {
                level = 4,
            },
            ["Quieting a Heart"] = {
                level = 7,
            },
            ["Recovering the Guar"] = {
                level = 10,
            },
            ["Rending Flames"] = {
                level = 7,
            },
            ["Restoring Order"] = {
                level = 10,
            },
            ["Restoring the Guardians"] = {
                level = 8,
            },
            ["Sadal's Final Defeat"] = {
                level = 15,
            },
            ["Savages of Stonefalls"] = {
                level = 13,
            },
            ["Saving the Son"] = {
                level = 15,
            },
            ["Shattering Mirror"] = {
                level = 13,
            },
            ["Stem the Tide"] = {
                level = 11,
            },
            ["Suspicious Silence"] = {
                level = 8,
            },
            ["Taking Precautions"] = {
                level = 15,
            },
            ["Taking the Tower"] = {
                level = 10,
            },
            ["The Brothers Will Rise"] = {
                level = 9,
            },
            ["The Coral Heart"] = {
                level = 10,
            },
            ["The Curse of Heimlyn Keep"] = {
                level = 12,
            },
            ["The Death of Balreth"] = {
                level = 8,
            },
            ["The Fate of a Friend"] = {
                level = 9,
            },
            ["The Fetish"] = {
                level = 13,
            },
            ["The General's Demise"] = {
                level = 12,
            },
            ["The Sapling"] = {
                level = 10,
            },
            ["The Truth about Spiders"] = {
                level = 10,
            },
            ["The Venom of Ahknara"] = {
                level = 8,
            },
            ["The Wizard's Tome"] = {
                level = 4,
            },
            ["This One's a Classic"] = {
                level = 15,
            },
            ["Through the Aftermath"] = {
                level = 5,
            },
            ["To Aid Davon's Watch"] = {
                level = 7,
            },
            ["To Ash Mountain"] = {
                level = 7,
            },
            ["To Fort Virak"] = {
                level = 10,
            },
            ["To the Mountain"] = {
                level = 10,
            },
            ["To the Tormented Spire"] = {
                level = 15,
            },
            ["Undermined"] = {
                level = 13,
            },
            ["Vengeance for House Dres"] = {
                level = 15,
            },
            ["Wake the Dead"] = {
                level = 7,
            },
            ["Waylaid Wine Merchant"] = {
                level = 13,
            },
            ["Wayward Son"] = {
                level = 5,
            },
            ["What Was Done Must Be Undone"] = {
                level = 12,
            },
            ["Window on the Past"] = {
                level = 9
			},
            ["A Son's Promise"] = {
                level = 5,
                dungeon = "Crow's Wood",
            },
            ["Decree of the Court"] = {
                level = 5,
                dungeon = "Crow's Wood",
            },
            ["Kings of the Grotto"] = {
                level = 12,
                dungeon = "Fungal Grotto",
            },
            ["Lighting the Shadows"] = {
                level = 50,
                dungeon = "Fungal Grotto",
            },
        },
        ["The Rift"] = {
            ["A Business Proposition"] = {
                level = 39,
            },
            ["A Diamond in the Root"] = {
                level = 42,
            },
            ["A Giant in Smokefrost Peaks"] = {
                level = 41,
            },
            ["A Grave Situation"] = {
                level = 40,
            },
            ["A Ritual in Smokefrost Peaks"] = {
                level = 43,
            },
            ["A Ritual in the Ragged Hills"] = {
                level = 43,
            },
            ["A Walk Above the Clouds"] = {
                level = 42,
            },
            ["Aiding Sigunn"] = {
                level = 38,
            },
            ["All's Fair"] = {
                level = 38,
            },
            ["Approaching Thunder"] = {
                level = 42,
            },
            ["Beneath the Stone"] = {
                level = 38,
            },
            ["Beneath the Surface"] = {
                level = 42,
            },
            ["Blood Upon the Soil"] = {
                level = 40,
            },
            ["Breaking the Coven"] = {
                level = 38,
            },
            ["Calling Hakra"] = {
                level = 40,
            },
            ["Concealed Weapons"] = {
                level = 39,
            },
            ["Dangerous Union"] = {
                level = 39,
            },
            ["Drink, Drink, and Be Merry"] = {
                level = 38,
            },
            ["Drinking Game"] = {
                level = 40,
            },
            ["Fierce Beasts of Ivarstead"] = {
                level = 40,
            },
            ["Finding Winter's Hammer"] = {
                level = 40,
            },
            ["Geirmund's Guardian"] = {
                level = 40,
            },
            ["Geirmund's Oath"] = {
                level = 40,
            },
            ["Gift of the Worm"] = {
                level = 39,
            },
            ["Guard the Knowledge"] = {
                level = 41,
            },
            ["Honrich Tower"] = {
                level = 41,
            },
            ["In His Wake"] = {
                level = 41,
            },
            ["Into the Outside"] = {
                level = 40,
            },
            ["Kalodar's Farewell"] = {
                level = 38,
            },
            ["Lost Companions"] = {
                level = 43,
            },
            ["Move out Miners"] = {
                level = 38,
            },
            ["Names of the Fallen"] = {
                level = 42,
            },
            ["Pinepeak Caverns"] = {
                level = 40,
            },
            ["Problems Into Profit"] = {
                level = 40,
            },
            ["Pulled Under"] = {
                level = 41,
            },
            ["Raise the Colors"] = {
                level = 38,
            },
            ["Redguard on the Run"] = {
                level = 40,
            },
            ["Research Subject"] = {
                level = 40,
            },
            ["Returning Winter's Bite"] = {
                level = 40,
            },
            ["Ritual at the Dragonshrine"] = {
                level = 43,
            },
            ["River of Names"] = {
                level = 42,
            },
            ["Save Your Voice"] = {
                level = 40,
            },
            ["Scouting the Mine"] = {
                level = 38,
            },
            ["Securing the Pass"] = {
                level = 42,
            },
            ["Shattered Hopes"] = {
                level = 41,
            },
            ["Shroud Hearth Barrow"] = {
                level = 40,
            },
            ["Smoke on the Horizon"] = {
                level = 38,
            },
            ["Soldier Down"] = {
                level = 41,
            },
            ["Song of Awakening"] = {
                level = 41,
            },
            ["Soul Harvest"] = {
                level = 39,
            },
            ["Stomping Sinmur"] = {
                level = 42,
            },
            ["Storming the Hall"] = {
                level = 38,
            },
            ["The Farmer's Champion"] = {
                level = 39,
            },
            ["The Rise of Sage Svari"] = {
                level = 38,
            },
            ["The Shackled Guardian"] = {
                level = 40,
            },
            ["The Shards of Wuuthrad"] = {
                level = 42,
            },
            ["The Thunder Breaks"] = {
                level = 42,
            },
            ["The Troubleshooter"] = {
                level = 38,
            },
            ["The Warding Way"] = {
                level = 38,
            },
            ["Those She Devours"] = {
                level = 42,
            },
            ["Through the Shroud"] = {
                level = 39,
            },
            ["To Honrich Tower"] = {
                level = 41,
            },
            ["To Nimalten"] = {
                level = 39,
            },
            ["To Pinepeak Caverns"] = {
                level = 40,
            },
            ["To Taarengrav"] = {
                level = 40,
            },
            ["To the King"] = {
                level = 42,
            },
            ["To Vernim Woods"] = {
                level = 38,
            },
            ["Tomb Beneath the Mountain"] = {
                level = 40,
            },
            ["Trial of the Body"] = {
                level = 40,
            },
            ["Trial of the Mind"] = {
                level = 40,
            },
            ["Trial of the Spirit"] = {
                level = 40,
            },
            ["Unearthed"] = {
                level = 38,
            },
            ["Where the Frostheart Grows"] = {
                level = 40,
            },
            ["Worm Cult Summoner"] = {
                level = 42,
            },
            ["Yngrel the Bloody"] = {
                level = 38,
            },
            ["A Valuable Distraction"] = {
                level = 39,
                dungeon = "Lion's Den",
            },
            ["Prisoner Dilemma"] = {
                level = 39,
                dungeon = "Lion's Den",
            },
            ["Fires of Battle"] = {
                level = 40,
                dungeon = "Blessed Crucible",
            },
        },
        -- Shared zones
        ["Coldharbour"] = {
            ["A Bargain With Shadows"] = {
                level = 47,
            },
            ["A Graveyard of Ships"] = {
                level = 49,
            },
            ["A Misplaced Pendant"] = {
                level = 46,
            },
            ["A Thorn in Your Side"] = {
                level = 47,
            },
            ["An Unusual Circumstance"] = {
                level = 45,
            },
            ["Between Blood and Bone"] = {
                level = 49,
            },
            ["Breaking the Shackle"] = {
                level = 48,
            },
            ["Crossing the Chasm"] = {
                level = 48,
            },
            ["Escape Coldharbour"] = {
                level = 1,
            },
            ["Hall of Judgment"] = {
                level = 46,
            },
            ["Into the Woods"] = {
                level = 45,
            },
            ["Light from the Darkness"] = {
                level = 46,
            },
            ["News of Fallen Kin"] = {
                level = 46,
            },
            ["Old Bones"] = {
                level = 48,
            },
            ["Saving Stibbons"] = {
                level = 45,
            },
            ["Special Blend"] = {
                level = 47,
            },
            ["The Anguish Gem"] = {
                level = 49,
            },
            ["The Army of Meridia"] = {
                level = 48,
            },
            ["The Citadel Must Fall"] = {
                level = 50,
            },
            ["The Endless War"] = {
                level = 47,
            },
            ["The Final Assault"] = {
                level = 50,
            },
            ["The Harvest Heart"] = {
                level = 49,
            },
            ["The Hollow City"] = {
                level = 45,
            },
            ["The Library of Dusk"] = {
                level = 44,
            },
            ["The Lost Lute"] = {
                level = 44,
            },
            ["The Shadow's Embrace"] = {
                level = 45,
            },
            ["The Soul-Meld Mage"] = {
                level = 46,
            },
            ["The Will of the Worm"] = {
                level = 47,
            },
            ["Through the Daedric Lens"] = {
                level = 44,
            },
            ["Truth, Lies, and Prisoners"] = {
                level = 44,
            },
            ["Vanus Unleashed"] = {
                level = 47,
            },
            ["What the Heart Wants"] = {
                level = 49,
            },
            ["Wisdom of the Ages"] = {
                level = 46,
            },
            ["Holes in the World"] = {
                level = 45,
                dungeon = "Village of the Lost",
            },
            ["Soul Survivors"] = {
                level = 45,
                dungeon = "Village of the Lost",
            },
            ["Mind of Madness"] = {
                level = 47,
                dungeon = "Vaults of Madness",
            },
        },
        ["Cyrodiil"] = {
			-- Bruma Quests
            ["Bring Down the Magister"] = {
                level = 50,
            },
            ["Capstone Caps"] = {
                level = 50,
            },
            ["Dangerously Low"] = {
                level = 50,
            },
            ["Enemy Reinforcements"] = {
                level = 50,
            },
            ["Know thy Enemy"] = {
                level = 50,
            },
            ["Lost and Alone"] = {
                level = 50,
            },
            ["Requests for Aid"] = {
                level = 50,
            },
            ["The Standing Stones"] = {
                level = 50,
            },
            ["The Unseen"] = {
                level = 50,
            },
            ["Timely Intervention"] = {
                level = 50,
            },
			-- Cheydinhal Quests
            ["A Debt Come Due"] = {
                level = 50,
            },
            ["Ayleid Treasure"] = {
                level = 50,
            },
            ["Bloodied Waters"] = {
                level = 50,
            },
            ["For Piety's Sake"] = {
                level = 50,
            },
            ["Keepsake"] = {
                level = 50,
            },
            ["Prisoners of War"] = {
                level = 50,
            },
            ["Spice"] = {
                level = 50,
            },
            ["Stacking the Odds"] = {
                level = 50,
            },
            ["The Burned Estate"] = {
                level = 50,
            },
            ["Thorns in Our Side"] = {
                level = 50,
            },
			-- Chorrol and Weynon Priory
            ["Abominations"] = {
                level = 50,
            },
            ["Black Dagger Supplies"] = {
                level = 50,
            },
            ["Claw of Akatosh"] = {
                level = 50,
            },
            ["Death to the Black Daggers!"] = {
                level = 50,
            },
            ["Field of Fire"] = {
                level = 50,
            },
            ["Guard Work is Never Done"] = {
                level = 50,
            },
            ["The Cache"] = {
                level = 50,
            },
            ["The High Cost of Lying"] = {
                level = 50,
            },
            ["Overdue Supplies"] = {
                level = 50,
            },
            ["The Lich"] = {
                level = 50,
            },
			-- Cropsford Quests
            ["Bloody Hand Spies!"] = {
                level = 50,
            },
            ["Crown Point"] = {
                level = 50,
            },
            ["Goblin's Delight"] = {
                level = 50,
            },
            ["Harvest Time"] = {
                level = 50,
            },
            ["Hedoran Estate"] = {
                level = 50,
            },
            ["Offerings to Zenithar"] = {
                level = 50,
            },
            ["Securing Knowledge"] = {
                level = 50,
            },
            ["Seeds of Hope"] = {
                level = 50,
            },
            ["The Dead of Culotte"] = {
                level = 50,
            },
            ["Timberscar Troubles"] = {
                level = 50,
            },
			-- Vlastarus Quests
            ["An Evil Presence"] = {
                level = 50,
            },
            ["Bear Essentials"] = {
                level = 50,
            },
            ["Death to the Crone"] = {
                level = 50,
            },
            ["Essence of Flame"] = {
                level = 50,
            },
            ["For a Friend"] = {
                level = 50,
            },
            ["Mementos"] = {
                level = 50,
            },
            ["Rock Bone Diplomacy"] = {
                level = 50,
            },
            ["Silver Scales"] = {
                level = 50,
            },
            ["Stolen Banner"] = {
                level = 50,
            },
            ["The Direct Approach"] = {
                level = 50,
            },
        },
        ["Craglorn"] = {
            ["Critical Mass"] = {
                level = 50,
            },
            ["Elemental Army"] = {
                level = 50,
            },
            ["Gem of the Stars"] = {
                level = 50,
            },
            ["Message Unknown"] = {
                level = 50,
            },
            ["Slithering Brood"] = {
                level = 50,
            },
            ["Strange Lexicon"] = {
                level = 50,
            },
            ["Supreme Power"] = {
                level = 50,
            },
            ["The Corrupted Stone"] = {
                level = 50,
            },
            ["The Fallen City of Shada"] = {
                level = 50,
            },
            ["The Missing Guardian"] = {
                level = 50,
            },
            ["The Reason We Fight"] = {
                level = 50,
            },
            ["The Seeker's Archive"] = {
                level = 50,
            },
            ["The Shattered and the Lost"] = {
                level = 50,
            },
            ["The Star-Gazers"] = {
                level = 50,
            },
            ["The Trials of Rahni'Za"] = {
                level = 50,
            },
            ["The Warrior's Call"] = {
                level = 50,
            },
            ["Trial of Martial Knowledge"] = {
                level = 50,
            },
            ["Trial of the True Path"] = {
                level = 50,
            },
            ["Waters Run Foul"] = {
                level = 50,
            },
        },
    },
}


-- Map local tables to global module.
HoW_QJ.DB = {
    quests = quests[KEY_LANG],
    stats = stats[KEY_LANG],
    zones = zones[KEY_LANG],
    types = types[KEY_LANG],
}
