--------------------------------------------------------------------------------
-- HoW-UI - Quest Journal Map Pins.
--------------------------------------------------------------------------------
-- Thank you Garkin: http://www.esoui.com/forums/showthread.php?t=1557
--------------------------------------------------------------------------------

--
-- Map pin paths
--
HoW_QJ.PINS = {
    names = {
        abandoned = "HoW_QJ_PIN_QUEST_ABANDONED",
        active    = "HoW_QJ_PIN_QUEST_ACTIVE",
        complete  = "HoW_QJ_PIN_QUEST_COMPLETE",
        unknown   = "HoW_QJ_PIN_QUEST_UNKNOWN",
    },
    filterText = {
        abandoned = "QJ - Abandoned quests",
        active    = "QJ - Active quests",
        complete  = "QJ - Completed quests",
        unknown   = "QJ - New quests",
    },
    textures = {
        default_32px = {
            abandoned = "HoW_QuestJournal/art/mappins/quest_abandoned_32px.dds",
            active    = "HoW_QuestJournal/art/mappins/quest_active_32px.dds",
            complete  = "HoW_QuestJournal/art/mappins/quest_complete_32px.dds",
            unknown   = "HoW_QuestJournal/art/mappins/quest_unknown_32px.dds",
        },
        default_64px = {
            abandoned = "HoW_QuestJournal/art/mappins/quest_abandoned_64px.dds",
            active    = "HoW_QuestJournal/art/mappins/quest_active_64px.dds",
            complete  = "HoW_QuestJournal/art/mappins/quest_complete_64px.dds",
            unknown   = "HoW_QuestJournal/art/mappins/quest_unknown_64px.dds",
        },
    },
    func = {
        createPins = {
        },
        tooltip = {
            abandoned = {
                creator = function(pin)
                    local quest = pin.m_PinTag.quest;
                    InformationTooltip:AddLine(string.format("|c%s%s|r (abandoned)", HoW_QJ.vars.colors.abandoned, quest.name))
                end,
                tooltip = InformationTooltip,
            },
            active = {
                creator = function(pin)
                    local quest = pin.m_PinTag.quest;
                    InformationTooltip:AddLine(string.format("|c%s%s|r (active)", HoW_QJ.vars.colors.active, quest.name))
                end,
                tooltip = InformationTooltip,
            },
            complete = {
                creator = function(pin)
                    local quest = pin.m_PinTag.quest;
                    InformationTooltip:AddLine(string.format("|c%s%s|r (completed)", HoW_QJ.vars.colors.complete, quest.name))
                end,
                tooltip = InformationTooltip,
            },
            unknown = {
                creator = function(pin)
                    --local locX, locY = pin:GetNormalizedPosition()
                    local quest = pin.m_PinTag.quest;
                    InformationTooltip:AddLine(string.format("|c%s%s|r (new)", HoW_QJ.vars.colors.unknown, quest.name))
                end,
                tooltip = InformationTooltip,
            },
        }
    },
}

--- Create map pins for given quest state.
-- @param pinManager
-- @param pinKey string with the pin types: abandoned, active, complete, unknown
-- @param questState int see STATE table in HoW_QuestJournal.lua for values.
-- @return void
HoW_QJ.PINS.func.CreateMapPins = function(pinManager, pinKey, questState)
    local pinType = HoW_QJ.PINS.names[pinKey]

    -- Do not render pins if conditions are not met
    if not ZO_WorldMap_IsCustomPinEnabled(_G[pinType]) then return end
    if (GetMapType() > MAPTYPE_ZONE) then return end
    if (GetMapContentType() == MAP_CONTENT_AVA) then
        if not HoW_QJ.vars.filters.pvp[pinKey] then
            return
        end
    else
        if not HoW_QJ.vars.filters.pve[pinKey] then
            return
        end
    end

    -- Check database for pins with location matching our quest state and create pins.
    local mapName = GetMapName()
    local zoneIndex = GetCurrentMapZoneIndex()
    local zoneName = HoW_QJ.DB.zones[""..zoneIndex]

    if HoW_QJ.DB.quests[mapName] then
        -- Pins for main zones
        zoneName = mapName
        for questName, q in pairs(HoW_QJ.DB.quests[zoneName]) do
            if HoW_QJ.vars.quests[zoneName] and HoW_QJ.vars.quests[zoneName][questName] then
                local quest = HoW_QJ.vars.quests[zoneName][questName]
                if quest.state == questState and quest.start and quest.start.agent and quest.start.agent.pin and quest.start.agent.mapname == zoneName then
                    pinManager:CreatePin(_G[pinType], quest.start, quest.start.agent.pin.x, quest.start.agent.pin.y)
                end
            end
        end
    elseif zoneName and HoW_QJ.DB.quests[zoneName] then
        -- Pins for subzones
        for questName, q in pairs(HoW_QJ.DB.quests[zoneName]) do
            if HoW_QJ.vars.quests[zoneName] and HoW_QJ.vars.quests[zoneName][questName] then
                local quest = HoW_QJ.vars.quests[zoneName][questName]
                if quest.state == questState and quest.start and quest.start.agent and quest.start.agent.pin and quest.start.agent.mapname == mapName then
                    pinManager:CreatePin(_G[pinType], quest.start, quest.start.agent.pin.x, quest.start.agent.pin.y)
                end
            end
        end
    end
end

HoW_QJ.PINS.func.createPins.abandoned = function(pinManager)
    HoW_QJ.PINS.func.CreateMapPins(pinManager, "abandoned", 3)
end

HoW_QJ.PINS.func.createPins.active = function(pinManager)
    HoW_QJ.PINS.func.CreateMapPins(pinManager, "active", 1)
end

HoW_QJ.PINS.func.createPins.complete = function(pinManager)
    HoW_QJ.PINS.func.CreateMapPins(pinManager, "complete", 2)
end

HoW_QJ.PINS.func.createPins.unknown = function(pinManager)
    HoW_QJ.PINS.func.CreateMapPins(pinManager, "unknown", 0)
end

--- Add checkboxes to the world map filter panel.
-- @param panel control either the pvePanel or pvpPanel.
-- @param mode string the panel type: pve or pvp
-- @param pinKey string with the pin types: abandoned, active, complete, unknown
-- @param pinType string the name of the map pin.
-- @param filterText string text for checkbox label.
-- @param filterState boolean initial state for checkbox.
HoW_QJ.PINS.func.AddWorldMapFilters = function(panel, mode, pinKey, pinType, filterText, filterState)
    d(pinKey, filterText, filterState)
    local checkBox = panel.checkBoxPool:AcquireObject()
    ZO_CheckButton_SetLabelText(checkBox, filterText)
    ZO_CheckButton_SetCheckState(checkBox, filterState)
    ZO_CheckButton_SetToggleFunction(checkBox,
        function(control, state)
            HoW_QJ.vars.filters[mode][pinKey] = state
            ZO_CheckButton_SetCheckState(control, state)
            ZO_WorldMap_RefreshCustomPinsOfType(_G[pinType])
        end)
    panel:AnchorControl(checkBox)
end
